@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "god-mode" "2.19.0"
+(define-package "god-mode" "20250820.259"
   "Minor mode for God-like command entering."
   '((emacs "26.3"))
   :url "https://github.com/emacsorphanage/god-mode"
